Standard input and output.
Functions
- ax_
console_ flush - Drains queued task output through the physical UART.
- ax_
console_ read_ bytes - Reads a slice of bytes from the console, returns the number of bytes read.
- ax_
console_ wait_ readable - Sleeps until task-console input becomes readable.
- ax_
console_ write_ bytes - Writes a slice of bytes to the console, returns the number of bytes written.
- ax_
console_ write_ fmt - Writes a formatted string through the sleepable TTY console path.