pub fn ax_wait_for_exit(task: AxTaskHandle) -> i32Expand description
Waits for the given task to exit, and returns its exit code (the
argument of ax_exit).
pub fn ax_wait_for_exit(task: AxTaskHandle) -> i32Waits for the given task to exit, and returns its exit code (the
argument of ax_exit).