ax_wait_queue_wake

Function ax_wait_queue_wake 

pub fn ax_wait_queue_wake(wq: &AxWaitQueueHandle, count: u32) -> usize
Wakes up one or more tasks in the wait queue.

The maximum number of tasks to wake up is specified by count. If count is u32::MAX, it will wake up all tasks in the wait queue. Returns the number of waiters selected for wakeup.