ax_wait_queue_wake_one_with

Function ax_wait_queue_wake_one_with 

pub fn ax_wait_queue_wake_one_with(wq: &AxWaitQueueHandle, func: impl Fn(u64))
Wakes up at most one task in the wait queue after performing an operation on it via the provided callback func.

The callback func is invoked while holding the wait-queue lock. If a task is woken, func is called with an implementation-defined u64 value associated with that task.