Module task

Module task 

Multi-threading management.

Functions

ax_exit
Exits the current task with the given exit code.
ax_sleep_until
Current task is going to sleep, it will be woken up at the given deadline.
ax_yield_now
Current task gives up the CPU time voluntarily, and switches to another ready task.